using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    ExecutableProduct(prefix, "csearch", :csearch),
    ExecutableProduct(prefix, "cindex", :cindex),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/tanmaykm/GoogleCodeSearchBuilder/releases/download/v0.1.2"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:i686, libc=:glibc) => ("$bin_prefix/GoogleCodeSearchBuilder.v0.1.2.i686-linux-gnu.tar.gz", "213aaeb93d5d01a03fae82b4d1f018865232cb936d8189a57edab0f46e8c645c"),
    Linux(:x86_64, libc=:glibc) => ("$bin_prefix/GoogleCodeSearchBuilder.v0.1.2.x86_64-linux-gnu.tar.gz", "d44229cde6a551fcc20a399bf43534ac5aabcb7991f7b6bf5726185556552725"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
